Markdown to reStructuredText Converter
======================================

|GitHub License| |Pepy Total Downlods|

Command-line tool to convert Markdown files to reStructuredText using
Pandoc.

Installation
------------

Install the converter using pip:

.. code:: bash

   pip install md-rst

Usage
-----

Run the converter from the command line:

.. code:: bash

   md-rst input.md output.rst

Replace input.md with the path to your input Markdown file and
output.rst with the desired output reStructuredText file.

License
-------

This project is licensed under the GNU-GPL3 License. Read LICENSE for
more information.

.. |GitHub License| image:: https://img.shields.io/github/license/croketillo/md-rst
.. |Pepy Total Downlods| image:: https://img.shields.io/pepy/dt/md-rst
